PoissonDecoder - LatentLego

Skip to content

# PoissonDecoder

### `latent.modules.decoder.PoissonDecoder`

Decoder with poisson reconstruction loss. Uses size factors to deal with count data.

#### `__init__(self, x_dim, name='poisson_decoder', hidden_units=[128, 128], reconstruction_loss='poisson', loss_name='poisson_loss', initializer='glorot_normal', **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`x_dim` | `int` | Integer indicating the number of dimensions in the input data. | required
`name` | `str` | String indicating the name of the model. | `'poisson_decoder'`
`hidden_units` | `Iterable[int]` | Number of hidden units in `DenseStack`. If set to `None` the model skips the `DenseStack` and reduces to a linear decoder (Svensson 2020). | `[128, 128]`
`reconstruction_loss` | `Union[Callable, str]` | Function to compute reconstruction loss. | `'poisson'`
`loss_name` | `str` | String indicating the name of the loss. | `'poisson_loss'`
`initializer` | `Union[str, Callable]` | Initializer for the kernel weights matrix (see `keras.initializers`) | `'glorot_normal'`
`**kwargs` | `` | Other arguments passed on to `DenseStack`. | `{}`